export type PayMethod = {
    label: string;
    value: PayType,
    icon: string;
    disabled: boolean
}

export const BACK_ORDER_ID = 'backOrderId'

export type BackInfo = {
    orderId: number;
}
export type OrderStateCallBack = (params: BackInfo & { isPay: boolean, isLimit?: boolean }) => void

export type PaymentParams = {
    payChannels?: PayChannel[],
    supportCombination?: boolean
}

export enum PayType {
    /**
     * 余额支付
     */
    BALANCE = 1,
    /**
     * 微信支付
     */
    WECHAT = 5,
    /**
     * 支付宝支付
     */
    ALIPAY = 6,
    /**
     * 微信 + 余额支付
     */
    WECHAT_BALANCE = 7,
    /**
     * 支付宝 + 余额支付
     */
    ALIPAY_BALANCE = 8,
    /**
     * 花呗支付
     */
    HUABEI = 10,
    /**
     * 花呗 + 余额支付
     */
    HUABEI_BALANCE = 11,
    /**
     * 花呗分期
     */
    HUABEI_STAGE = 12,
    /**
     * 花呗分期 + 余额支付
     */
    HUABEI_STAGE_BALANCE = 13

}

/**
 * 余额支付方式默认支持， 无需声明
 */
export enum PayChannel {
    WX_MWEB = 'WX_MWEB',
    WX_JSAPI = 'WX_JSAPI',
    WX_NATIVE = 'WX_NATIVE',
    WX_APP = 'WX_APP',
    ALI_WAP = 'ALI_WAP',
    ALI_APP = 'ALI_APP',
    ALI_PC = 'ALI_PC',
    ALI_QR = 'ALI_QR',
    ALI_PCREDIT = 'ALI_PCREDIT'
}

export type ToPayParams = {
    orderId: number;
    subOrderIds?: string;
    totalAmount: number;
    payType: PayType;
    /**
     * 支付宝h5支付失败回调地址
     * doc: https://opendocs.alipay.com/open/203/105285#%E9%87%8D%E8%A6%81%E5%85%A5%E5%8F%82%E8%AF%B4%E6%98%8E_3
     */
    quitUrl?: string;
    /**
     * 支付宝h5支付成功回调地址
     * doc: https://opendocs.alipay.com/open/203/105285#%E9%87%8D%E8%A6%81%E5%85%A5%E5%8F%82%E8%AF%B4%E6%98%8E_3
     */
    returnUrl?: string;
    /**
     * 微信h5支付回调地址
     * doc: https://pay.weixin.qq.com/wiki/doc/apiv3/wxpay/pay/combine/chapter10_1.shtml
     */
    redirectUrl?: string;
    /**
     * 支付记录id, 采用余额支付的时候如果前端有此值就带过来
     */
}

export enum PayError {
    WECHAT_JSSDK = "WECHAT_JSSDK",
    BALANCE = 'BALANCE',
    VALIDATE = 'VALIDATE',
    BACKEND = 'BACKEND',
    WECHAT_H5_BREAK = 'WECHAT_H5_BREAK',
    ALIPAY_H5_BREAK = 'ALIPAY_H5_BREAK',
    UNKNOWN = 'UNKNOWN'
}
export enum PayErrorMessage {
    BALANCE_EMPTY = '余额不足',
    WECHAT_REDIRECT_URL_MISSING= `请填写微信回调地址页面 'redirectUrl`,
    WECHAT_REDIRECT_URL_ENCODE = 'redirectUrl需要encode',
    WECHAT_PAY_CHANNEL_MISSING =`缺少渠道参数：'WX_MWEB','WX_JSAPI'`,
    ALIPAY_QUIT_URL_MISSING = `缺少支付失败回调地址：'quitUrl'`,
    ALIPAY_RETURN_URL_MISSING =  `缺少支付成功回调地址：'returnUrl'`,
    ALIPAY_PAY_CHANNEL_MISSING = `缺少持的渠道参数：'ALI_WAP'`,
    WECHAT_JSSDK_PAY_ERROR = '微信JSSDK支付失败',
    WECHAT_H5_PAY_BREAK = '微信h5支付中断',
    ALIPAY_H5_PAY_BREAK = '支付宝支付中断',
}

export type ToPayReturns = {
    errorMessage?: PayErrorMessage
    errorType: PayError
    success: boolean
    payUrl?: string
}

export interface DoUnifiedParams extends Omit<ToPayParams, 'totalAmount' | 'redirectUrl'> {
    payChannel?: PayChannel,
    payBalance: number,
    payAmount: number
}

export interface WechatPayParams {
    appId: string,
    timeStamp: string,
    nonceStr: string,
    signType: string,
    paySign: string,
    package: string
}

export const FULL_PAY_METHODS: PayMethod[] = [
    {
        label: '余额',
        value: PayType.BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/balance.png',
        disabled: false
    },
    {
        label: '微信支付',
        value: PayType.WECHAT,
        icon: 'https://static.ydlcdn.com/m/order/weixinzhifu.png',
        disabled: false
    },
    {
        label: '支付宝',
        value: PayType.ALIPAY,
        icon: 'https://static.ydlcdn.com/m/order/zhifubaozhifu.png',
        disabled: false
    },
    {
        label: '微信支付',
        value: PayType.WECHAT_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/weixinzhifu.png',
        disabled: false
    },
    {
        label: '支付宝',
        value: PayType.ALIPAY_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/zhifubaozhifu.png',
        disabled: false
    },
    {
        label: '花呗',
        value: PayType.HUABEI,
        icon: 'https://static.ydlcdn.com/m/order/huabei.png',
        disabled: false
    },
    {
        label: '花呗',
        value: PayType.HUABEI_BALANCE,
        icon: 'https://static.ydlcdn.com/m/order/huabei.png',
        disabled: false  
    }
]